@@ -31,6 +31,7 @@ const ContactPlace = imports.contactPlace;
 const Geoclue = imports.geoclue;
 const Location = imports.location;
 const Maps = imports.gi.GnomeMaps;
+const MapSource = imports.mapSource;
 const MapWalker = imports.mapWalker;
 const Place = imports.place;
 const PlaceMarker = imports.placeMarker;
@@ -41,10 +42,8 @@ const Utils = imports.utils;
 
 const MapType = {
     LOCAL: 'MapsLocalSource',
-    STREET:  Champlain.MAP_SOURCE_OSM_MAPQUEST,
-    AERIAL:  Champlain.MAP_SOURCE_OSM_AERIAL_MAP,
-    CYCLING: Champlain.MAP_SOURCE_OSM_CYCLE_MAP,
-    TRANSIT: Champlain.MAP_SOURCE_OSM_TRANSPORT_MAP
+    STREET: 'MapsStreetSource',
+    AERIAL: 'MapsAerialSource'
 };
 
 const MapMinZoom = 2;
@@ -82,7 +81,6 @@ const MapView = new Lang.Class({
         this.view = this._initView();
         this._initLayers();
 
-        this._factory = Champlain.MapSourceFactory.dup_default();
         this.setMapType(mapType);
 
         this._updateUserLocation();
@@ -156,8 +154,10 @@ const MapView = new Lang.Class({
             return;
 
         if (mapType !== MapType.LOCAL) {
-            let source = this._factory.create_cached_source(mapType);
-            this.view.map_source = source;
+            if (mapType === MapType.AERIAL)
+                this.view.map_source = MapSource.createAerialSource();
+            else
+                this.view.map_source = MapSource.createStreetSource();
         } else {
             let renderer = new Champlain.ImageRenderer();
             let source = new Maps.FileTileSource({
